==> jc-1.4.0.tar.gz: gnu/regexp/RE__24IntPair.h <==
// final class gnu.regexp.RE$IntPair

// class file dependencies
// @dep_class d2847c089fbc4ff1 gnu_regexp_RE__24IntPair
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_RE__24IntPair_H_
#define _JC_gnu_regexp_RE__24IntPair_H_

// Forward structure declarations
struct _jc_gnu_regexp_RE__241$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_regexp_RE__24IntPair$sub_refs	_jc_gnu_regexp_RE__24IntPair$sub_refs;
typedef struct _jc_gnu_regexp_RE__24IntPair$sub_nonrefs	_jc_gnu_regexp_RE__24IntPair$sub_nonrefs;
typedef struct _jc_gnu_regexp_RE__24IntPair$refs	_jc_gnu_regexp_RE__24IntPair$refs;
typedef struct _jc_gnu_regexp_RE__24IntPair$nonrefs	_jc_gnu_regexp_RE__24IntPair$nonrefs;
typedef struct _jc_gnu_regexp_RE__24IntPair$object	_jc_gnu_regexp_RE__24IntPair$object;

typedef const struct _jc_gnu_regexp_RE__24IntPair$vmethods	_jc_gnu_regexp_RE__24IntPair$vmethods;
typedef const struct _jc_gnu_regexp_RE__24IntPair$vtable	_jc_gnu_regexp_RE__24IntPair$vtable;
typedef const struct _jc_gnu_regexp_RE__24IntPair$vtype	_jc_gnu_regexp_RE__24IntPair$vtype;

// Constructors
extern void _jc_gnu_regexp_RE__24IntPair$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_regexp_RE__24IntPair$object *);
extern void _jc_gnu_regexp_RE__24IntPair$method$_init$3727815867c797ab(_jc_env *, struct _jc_gnu_regexp_RE__24IntPair$object *, struct _jc_gnu_regexp_RE__241$object *);

// Virtual methods structure
struct _jc_gnu_regexp_RE__24IntPair$vmethods {
};

// Vtable
struct _jc_gnu_regexp_RE__24IntPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_RE__24IntPair$vmethods	gnu_regexp_RE__24IntPair;
};

// Vtype
struct _jc_gnu_regexp_RE__24IntPair$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RE__24IntPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RE__24IntPair$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RE__24IntPair$refs {
    _jc_gnu_regexp_RE__24IntPair$sub_refs	gnu_regexp_RE__24IntPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RE__24IntPair$sub_nonrefs {
	jint	first;
	jint	second;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RE__24IntPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_RE__24IntPair$sub_nonrefs	gnu_regexp_RE__24IntPair;
};

// Object instance structure
struct _jc_gnu_regexp_RE__24IntPair$object {
	_jc_gnu_regexp_RE__24IntPair$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RE__24IntPair$vtype	*vtype;
	_jc_gnu_regexp_RE__24IntPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RE__24IntPair$vtype _jc_gnu_regexp_RE__24IntPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RE__24IntPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RE__24IntPair$class_object;

#endif	/* _JC_gnu_regexp_RE__24IntPair_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RE__24IntPair.h <==
// final class gnu.regexp.RE$IntPair

// class file dependencies
// @dep_class d2847c089fbc4ff1 gnu_regexp_RE__24IntPair
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_RE__24IntPair_H_
#define _JC_gnu_regexp_RE__24IntPair_H_

// Forward structure declarations
struct _jc_gnu_regexp_RE__241$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_regexp_RE__24IntPair$sub_refs	_jc_gnu_regexp_RE__24IntPair$sub_refs;
typedef struct _jc_gnu_regexp_RE__24IntPair$sub_nonrefs	_jc_gnu_regexp_RE__24IntPair$sub_nonrefs;
typedef struct _jc_gnu_regexp_RE__24IntPair$refs	_jc_gnu_regexp_RE__24IntPair$refs;
typedef struct _jc_gnu_regexp_RE__24IntPair$nonrefs	_jc_gnu_regexp_RE__24IntPair$nonrefs;
typedef struct _jc_gnu_regexp_RE__24IntPair$object	_jc_gnu_regexp_RE__24IntPair$object;

typedef const struct _jc_gnu_regexp_RE__24IntPair$vmethods	_jc_gnu_regexp_RE__24IntPair$vmethods;
typedef const struct _jc_gnu_regexp_RE__24IntPair$vtable	_jc_gnu_regexp_RE__24IntPair$vtable;
typedef const struct _jc_gnu_regexp_RE__24IntPair$vtype	_jc_gnu_regexp_RE__24IntPair$vtype;

// Constructors
extern void _jc_gnu_regexp_RE__24IntPair$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_regexp_RE__24IntPair$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_regexp_RE__24IntPair$method$_init$3727815867c797ab(_jc_env *, struct _jc_gnu_regexp_RE__24IntPair$object *, struct _jc_gnu_regexp_RE__241$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_regexp_RE__24IntPair$vmethods {
};

// Vtable
struct _jc_gnu_regexp_RE__24IntPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_RE__24IntPair$vmethods	gnu_regexp_RE__24IntPair;
};

// Vtype
struct _jc_gnu_regexp_RE__24IntPair$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RE__24IntPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RE__24IntPair$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RE__24IntPair$refs {
    _jc_gnu_regexp_RE__24IntPair$sub_refs	gnu_regexp_RE__24IntPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RE__24IntPair$sub_nonrefs {
	jint	first;
	jint	second;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RE__24IntPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_RE__24IntPair$sub_nonrefs	gnu_regexp_RE__24IntPair;
};

// Object instance structure
struct _jc_gnu_regexp_RE__24IntPair$object {
	_jc_gnu_regexp_RE__24IntPair$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RE__24IntPair$vtype	*vtype;
	_jc_gnu_regexp_RE__24IntPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RE__24IntPair$vtype _jc_gnu_regexp_RE__24IntPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RE__24IntPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RE__24IntPair$class_object;

#endif	/* _JC_gnu_regexp_RE__24IntPair_H_ */
